@@ -4,7 +4,7 @@
 -- License     :  BSD-3-Clause
 -- Maintainer  :  Oleg Grenrus <oleg.grenrus@iki.fi>
 --
--- This module re-exports the @GitHub.Data.@ and "Github.Auth" submodules.
+-- This module re-exports the @GitHub.Data.@ and "GitHub.Auth" submodules.
 module GitHub.Data (
     -- * Tagged types
     -- ** Name
@@ -30,6 +30,8 @@ module GitHub.Data (
     mkRepoId,
     fromUserId,
     fromOrganizationId,
+    -- * IssueNumber
+    IssueNumber (..),
     -- * Module re-exports
     module GitHub.Auth,
     module GitHub.Data.Activities,
@@ -46,6 +48,7 @@ module GitHub.Data (
     module GitHub.Data.Issues,
     module GitHub.Data.Milestone,
     module GitHub.Data.Options,
+    module GitHub.Data.PublicSSHKeys,
     module GitHub.Data.PullRequests,
     module GitHub.Data.RateLimit,
     module GitHub.Data.Releases,
@@ -79,6 +82,7 @@ import GitHub.Data.Issues
 import GitHub.Data.Milestone
 import GitHub.Data.Name
 import GitHub.Data.Options
+import GitHub.Data.PublicSSHKeys
 import GitHub.Data.PullRequests
 import GitHub.Data.RateLimit
 import GitHub.Data.Releases
