@@ -64,3 +64,22 @@ instance Binary EditComment
 
 instance ToJSON EditComment where
     toJSON (EditComment b) = object [ "body" .= b ]
+
+data NewPullComment = NewPullComment
+    { newPullCommentCommit   :: !Text
+    , newPullCommentPath     :: !Text
+    , newPullCommentPosition :: !Int
+    , newPullCommentBody     :: !Text
+    }
+  deriving (Show, Data, Typeable, Eq, Ord, Generic)
+
+instance NFData NewPullComment where rnf = genericRnf
+instance Binary NewPullComment
+
+instance ToJSON NewPullComment where
+    toJSON (NewPullComment c path pos b) =
+        object [ "body" .= b
+               , "commit_id" .= c
+               , "path" .= path
+               , "position" .= pos
+               ]
