@@ -184,11 +184,11 @@ instance NFData GitUser where rnf = genericRnf
 instance Binary GitUser
 
 data File = File
-    { fileBlobUrl   :: !URL
+    { fileBlobUrl   :: !(Maybe URL)
     , fileStatus    :: !Text
-    , fileRawUrl    :: !URL
+    , fileRawUrl    :: !(Maybe URL)
     , fileAdditions :: !Int
-    , fileSha       :: !Text
+    , fileSha       :: !(Maybe Text)
     , fileChanges   :: !Int
     , filePatch     :: !(Maybe Text)
     , fileFilename  :: !Text
@@ -251,11 +251,11 @@ instance FromJSON GitUser where
 
 instance FromJSON File where
     parseJSON = withObject "File" $ \o -> File
-        <$> o .: "blob_url"
+        <$> o .:? "blob_url"
         <*> o .: "status"
-        <*> o .: "raw_url"
+        <*> o .:? "raw_url"
         <*> o .: "additions"
-        <*> o .: "sha"
+        <*> o .:? "sha"
         <*> o .: "changes"
         <*> o .:? "patch"
         <*> o .: "filename"
