@@ -14,6 +14,7 @@ module GitHub.Data.Repos where
 import GitHub.Data.Definitions
 import GitHub.Data.Id          (Id)
 import GitHub.Data.Name        (Name)
+import GitHub.Data.Request     (IsPathPart (..))
 import GitHub.Data.URL         (URL)
 import GitHub.Internal.Prelude
 import Prelude ()
@@ -38,6 +39,7 @@ data Repo = Repo
     , repoFork            :: !(Maybe Bool)
     , repoGitUrl          :: !(Maybe URL)
     , repoPrivate         :: !Bool
+    , repoArchived        :: !Bool
     , repoCloneUrl        :: !(Maybe URL)
     , repoSize            :: !(Maybe Int)
     , repoUpdatedAt       :: !(Maybe UTCTime)
@@ -157,6 +159,7 @@ instance FromJSON Repo where
         <*> o .: "fork"
         <*> o .:? "git_url"
         <*> o .: "private"
+        <*> o .:? "archived" .!= False
         <*> o .:? "clone_url"
         <*> o .:? "size"
         <*> o .:? "updated_at"
@@ -255,3 +258,13 @@ instance FromJSON a => FromJSON (HM.HashMap Language a) where
         mapKey f = HM.fromList . map (first f) . HM.toList
 #endif
 #endif
+
+data ArchiveFormat
+    = ArchiveFormatTarball -- ^ ".tar.gz" format
+    | ArchiveFormatZipball -- ^ ".zip" format
+    deriving (Show, Eq, Ord, Enum, Bounded, Typeable, Data, Generic)
+
+instance IsPathPart ArchiveFormat where
+    toPathPart af = case af of
+        ArchiveFormatTarball -> "tarball"
+        ArchiveFormatZipball -> "zipball"
