@@ -1,8 +1,9 @@
-{-# LANGUAGE CPP                #-}
-{-# LANGUAGE FlexibleContexts   #-}
-{-# LANGUAGE GADTs              #-}
-{-# LANGUAGE KindSignatures     #-}
-{-# LANGUAGE StandaloneDeriving #-}
+{-# LANGUAGE CPP                   #-}
+{-# LANGUAGE FlexibleContexts      #-}
+{-# LANGUAGE FlexibleInstances     #-}
+{-# LANGUAGE GADTs                 #-}
+{-# LANGUAGE KindSignatures        #-}
+{-# LANGUAGE MultiParamTypeClasses #-}
 -----------------------------------------------------------------------------
 -- |
 -- License     :  BSD-3-Clause
@@ -29,7 +30,8 @@
 -- > githubRequest = singleton
 module GitHub.Request (
     -- * Types
-    Request(..),
+    Request,
+    GenRequest (..),
     CommandMethod(..),
     toMethod,
     Paths,
@@ -42,45 +44,46 @@ module GitHub.Request (
     executeRequestMaybe,
     unsafeDropAuthRequirements,
     -- * Helpers
+    Accept (..),
+    ParseResponse (..),
     makeHttpRequest,
-    makeHttpSimpleRequest,
-    parseResponse,
     parseStatus,
+    StatusMap,
     getNextUrl,
     performPagedRequest,
+    parseResponseJSON,
+    -- ** Preview
+    PreviewAccept (..),
+    PreviewParseResponse (..),
     ) where
 
 import GitHub.Internal.Prelude
 import Prelude ()
 
-#if MIN_VERSION_mtl(2,2,0)
-import Control.Monad.Except (MonadError (..))
-#else
-import Control.Monad.Error (MonadError (..))
-#endif
+import Control.Monad.Error.Class (MonadError (..))
 
 import Control.Monad              (when)
 import Control.Monad.Catch        (MonadCatch (..), MonadThrow)
 import Control.Monad.Trans.Class  (lift)
 import Control.Monad.Trans.Except (ExceptT (..), runExceptT)
-import Data.Aeson.Compat          (eitherDecode)
-import Data.List                  (find)
+import Data.Aeson                 (eitherDecode)
+import Data.List                  (find, intercalate)
+import Data.String                (fromString)
+import Data.Tagged                (Tagged (..))
+import Data.Version               (showVersion)
 
 import Network.HTTP.Client
-       (HttpException (..), Manager, RequestBody (..), Response (..),
-       applyBasicAuth, getUri, httpLbs, method, newManager, redirectCount,
-       requestBody, requestHeaders, setQueryString, setRequestIgnoreStatus)
-import Network.HTTP.Client.TLS  (tlsManagerSettings)
+       (HttpException (..), Manager, RequestBody (..), Response (..), getUri,
+       httpLbs, method, newManager, redirectCount, requestBody, requestHeaders,
+       setQueryString, setRequestIgnoreStatus)
 import Network.HTTP.Link.Parser (parseLinkHeaderBS)
 import Network.HTTP.Link.Types  (Link (..), LinkParam (..), href, linkParams)
 import Network.HTTP.Types       (Method, RequestHeaders, Status (..))
-import Network.URI              (URI, parseURIReference, relativeTo)
-
-#if !MIN_VERSION_http_client(0,5,0)
-import qualified Control.Exception  as E
-import           Network.HTTP.Types (ResponseHeaders)
-#endif
+import Network.URI
+       (URI, escapeURIString, isUnescapedInURIComponent, parseURIReference,
+       relativeTo)
 
+import qualified Data.ByteString              as BS
 import qualified Data.ByteString.Lazy         as LBS
 import qualified Data.Text                    as T
 import qualified Data.Text.Encoding           as TE
@@ -88,19 +91,47 @@ import qualified Data.Vector                  as V
 import qualified Network.HTTP.Client          as HTTP
 import qualified Network.HTTP.Client.Internal as HTTP
 
-import GitHub.Auth         (Auth (..))
-import GitHub.Data         (Error (..))
+#ifdef MIN_VERSION_http_client_tls
+import Network.HTTP.Client.TLS (tlsManagerSettings)
+#else
+import Network.HTTP.Client.OpenSSL (opensslManagerSettings, withOpenSSL)
+
+import qualified OpenSSL.Session          as SSL
+import qualified OpenSSL.X509.SystemStore as SSL
+#endif
+
+import GitHub.Auth              (Auth, AuthMethod, endpoint, setAuthRequest)
+import GitHub.Data              (Error (..))
+import GitHub.Data.PullRequests (MergeResult (..))
 import GitHub.Data.Request
 
--- | Execute 'Request' in 'IO'
-executeRequest :: Auth -> Request k a -> IO (Either Error a)
-executeRequest auth req = do
-    manager <- newManager tlsManagerSettings
-    x <- executeRequestWithMgr manager auth req
-#if !MIN_VERSION_http_client(0, 4, 18)
-    closeManager manager
+import Paths_github (version)
+
+#ifdef MIN_VERSION_http_client_tls
+withOpenSSL :: IO a -> IO a
+withOpenSSL = id
+#else
+tlsManagerSettings :: HTTP.ManagerSettings
+tlsManagerSettings = opensslManagerSettings $ do
+    ctx <- SSL.context
+    SSL.contextAddOption ctx SSL.SSL_OP_NO_SSLv2
+    SSL.contextAddOption ctx SSL.SSL_OP_NO_SSLv3
+    SSL.contextAddOption ctx SSL.SSL_OP_NO_TLSv1
+    SSL.contextSetCiphers ctx "ECDHE-ECDSA-AES256-GCM-SHA384:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-CHACHA20-POLY1305:ECDHE-RSA-CHACHA20-POLY1305:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES256-SHA384:ECDHE-RSA-AES256-SHA384:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA256"
+    SSL.contextLoadSystemCerts ctx
+    SSL.contextSetVerificationMode ctx $ SSL.VerifyPeer True True Nothing
+    return ctx
 #endif
-    pure x
+
+-- | Execute 'Request' in 'IO'
+executeRequest
+    :: (AuthMethod am, ParseResponse mt a)
+    => am
+    -> GenRequest mt rw a
+    -> IO (Either Error a)
+executeRequest auth req = withOpenSSL $ withOpenSSL $ do
+    manager <- newManager tlsManagerSettings
+    executeRequestWithMgr manager auth req
 
 lessFetchCount :: Int -> FetchCount -> Bool
 lessFetchCount _ FetchAll         = True
@@ -108,9 +139,10 @@ lessFetchCount i (FetchAtLeast j) = i < fromIntegral j
 
 -- | Like 'executeRequest' but with provided 'Manager'.
 executeRequestWithMgr
-    :: Manager
-    -> Auth
-    -> Request k a
+    :: (AuthMethod am, ParseResponse mt a)
+    => Manager
+    -> am
+    -> GenRequest mt rw a
     -> IO (Either Error a)
 executeRequestWithMgr mgr auth req = runExceptT $ do
     httpReq <- makeHttpRequest (Just auth) req
@@ -119,225 +151,131 @@ executeRequestWithMgr mgr auth req = runExceptT $ do
     httpLbs' :: HTTP.Request -> ExceptT Error IO (Response LBS.ByteString)
     httpLbs' req' = lift (httpLbs req' mgr) `catch` onHttpException
 
-    performHttpReq :: HTTP.Request -> Request k b -> ExceptT Error IO b
-    performHttpReq httpReq (SimpleQuery sreq)   =
-        performHttpReq' httpReq sreq
-    performHttpReq httpReq (HeaderQuery _ sreq) =
-        performHttpReq' httpReq sreq
-    performHttpReq httpReq (StatusQuery sm _)   = do
+    performHttpReq :: forall rw mt b. ParseResponse mt b => HTTP.Request -> GenRequest mt rw b -> ExceptT Error IO b
+    performHttpReq httpReq Query {} = do
         res <- httpLbs' httpReq
-        parseStatus sm  . responseStatus $ res
-    performHttpReq httpReq (RedirectQuery _)   = do
-        res <- httpLbs' httpReq
-        parseRedirect (getUri httpReq) res
+        unTagged (parseResponse httpReq res :: Tagged mt (ExceptT Error IO b))
 
-    performHttpReq' :: FromJSON b => HTTP.Request -> SimpleRequest k b -> ExceptT Error IO b
-    performHttpReq' httpReq Query {} = do
-        res <- httpLbs' httpReq
-        parseResponse res
-    performHttpReq' httpReq (PagedQuery _ _ l) =
-        performPagedRequest httpLbs' predicate httpReq
+    performHttpReq httpReq (PagedQuery _ _ l) =
+        unTagged (performPagedRequest httpLbs' predicate httpReq :: Tagged mt (ExceptT Error IO b))
       where
         predicate v = lessFetchCount (V.length v) l
-    performHttpReq' httpReq (Command m _ _) = do
-        res <- httpLbs' httpReq
-        case m of
-             Delete -> pure ()
-             Put'   -> pure ()
-             _      -> parseResponse res
 
+    performHttpReq httpReq (Command _ _ _) = do
+        res <- httpLbs' httpReq
+        unTagged (parseResponse httpReq res :: Tagged mt (ExceptT Error IO b))
 
 -- | Like 'executeRequest' but without authentication.
-executeRequest' ::Request 'RO a -> IO (Either Error a)
-executeRequest' req = do
+executeRequest' :: ParseResponse mt a => GenRequest mt 'RO a -> IO (Either Error a)
+executeRequest' req = withOpenSSL $ do
     manager <- newManager tlsManagerSettings
-    x <- executeRequestWithMgr' manager req
-#if !MIN_VERSION_http_client(0, 4, 18)
-    closeManager manager
-#endif
-    pure x
+    executeRequestWithMgr' manager req
 
 -- | Like 'executeRequestWithMgr' but without authentication.
 executeRequestWithMgr'
-    :: Manager
-    -> Request 'RO a
+    :: ParseResponse mt a
+    => Manager
+    -> GenRequest mt 'RO a
     -> IO (Either Error a)
 executeRequestWithMgr' mgr req = runExceptT $ do
-    httpReq <- makeHttpRequest Nothing req
+    httpReq <- makeHttpRequest (Nothing :: Maybe Auth) req
     performHttpReq httpReq req
   where
     httpLbs' :: HTTP.Request -> ExceptT Error IO (Response LBS.ByteString)
     httpLbs' req' = lift (httpLbs req' mgr) `catch` onHttpException
 
-    performHttpReq :: HTTP.Request -> Request 'RO b -> ExceptT Error IO b
-    performHttpReq httpReq (SimpleQuery sreq)   =
-        performHttpReq' httpReq sreq
-    performHttpReq httpReq (HeaderQuery _ sreq) =
-        performHttpReq' httpReq sreq
-    performHttpReq httpReq (StatusQuery sm _)   = do
+    performHttpReq :: forall mt b. ParseResponse mt b => HTTP.Request -> GenRequest mt 'RO b -> ExceptT Error IO b
+    performHttpReq httpReq Query {} = do
         res <- httpLbs' httpReq
-        parseStatus sm  . responseStatus $ res
-    performHttpReq httpReq (RedirectQuery _)   = do
-        res <- httpLbs' httpReq
-        parseRedirect (getUri httpReq) res
-
-    performHttpReq' :: FromJSON b => HTTP.Request -> SimpleRequest 'RO b -> ExceptT Error IO b
-    performHttpReq' httpReq Query {} = do
-        res <- httpLbs' httpReq
-        parseResponse res
-    performHttpReq' httpReq (PagedQuery _ _ l) =
-        performPagedRequest httpLbs' predicate httpReq
+        unTagged (parseResponse httpReq res :: Tagged mt (ExceptT Error IO b))
+    performHttpReq httpReq (PagedQuery _ _ l) =
+        unTagged (performPagedRequest httpLbs' predicate httpReq :: Tagged mt (ExceptT Error IO b))
       where
         predicate v = lessFetchCount (V.length v) l
 
 -- | Helper for picking between 'executeRequest' and 'executeRequest''.
 --
 -- The use is discouraged.
-executeRequestMaybe :: Maybe Auth -> Request 'RO a -> IO (Either Error a)
+executeRequestMaybe
+    :: (AuthMethod am, ParseResponse mt a)
+    => Maybe am
+    -> GenRequest mt 'RO a
+    -> IO (Either Error a)
 executeRequestMaybe = maybe executeRequest' executeRequest
 
 -- | Partial function to drop authentication need.
-unsafeDropAuthRequirements :: Request k' a -> Request k a
-unsafeDropAuthRequirements (SimpleQuery (Query ps qs)) =
-    SimpleQuery (Query ps qs)
-unsafeDropAuthRequirements r                 =
+unsafeDropAuthRequirements :: GenRequest mt rw' a -> GenRequest mt rw a
+unsafeDropAuthRequirements (Query ps qs) = Query ps qs
+unsafeDropAuthRequirements r             =
     error $ "Trying to drop authenatication from" ++ show r
 
-------------------------------------------------------------------------------
--- Tools
-------------------------------------------------------------------------------
+-------------------------------------------------------------------------------
+-- Parse response
+-------------------------------------------------------------------------------
 
--- | Create @http-client@ 'Request'.
---
--- * for 'PagedQuery', the initial request is created.
--- * for 'Status', the 'Request' for underlying 'Request' is created,
---   status checking is modifying accordingly.
---
--- @
--- parseResponse :: 'Maybe' 'Auth' -> 'Request' k a -> 'Maybe' 'Request'
--- @
-makeHttpRequest
-    :: MonadThrow m
-    => Maybe Auth
-    -> Request k a
-    -> m HTTP.Request
-makeHttpRequest auth r = case r of
-    SimpleQuery req ->
-        makeHttpSimpleRequest auth req
-    StatusQuery sm req -> do
-        req' <- makeHttpSimpleRequest auth req
-        return $ setCheckStatus (Just sm) req'
-    HeaderQuery h req -> do
-        req' <- makeHttpSimpleRequest auth req
-        return $ req' { requestHeaders = h <> requestHeaders req' }
-    RedirectQuery req -> do
-        req' <- makeHttpSimpleRequest auth req
-        return $ setRequestIgnoreStatus $ req' { redirectCount = 0 }
+class Accept (mt :: MediaType *) where
+    contentType :: Tagged mt BS.ByteString
+    contentType = Tagged "application/json" -- default is JSON
 
-makeHttpSimpleRequest
-    :: MonadThrow m
-    => Maybe Auth
-    -> SimpleRequest k a
-    -> m HTTP.Request
-makeHttpSimpleRequest auth r = case r of
-    Query paths qs -> do
-        req <- parseUrl' $ url paths
-        return
-            $ setReqHeaders
-            . setCheckStatus Nothing
-            . setAuthRequest auth
-            . setQueryString qs
-            $ req
-    PagedQuery paths qs _ -> do
-        req <- parseUrl' $ url paths
-        return
-            $ setReqHeaders
-            . setCheckStatus Nothing
-            . setAuthRequest auth
-            . setQueryString qs
-            $ req
-    Command m paths body -> do
-        req <- parseUrl' $ url paths
-        return
-            $ setReqHeaders
-            . setCheckStatus Nothing
-            . setAuthRequest auth
-            . setBody body
-            . setMethod (toMethod m)
-            $ req
-  where
-    parseUrl' :: MonadThrow m => Text -> m HTTP.Request
-#if MIN_VERSION_http_client(0,4,30)
-    parseUrl' = HTTP.parseRequest . T.unpack
-#else
-    parseUrl' = HTTP.parseUrl . T.unpack
-#endif
+    modifyRequest :: Tagged mt (HTTP.Request -> HTTP.Request)
+    modifyRequest = Tagged id
 
-    url :: Paths -> Text
-    url paths = baseUrl <> "/" <> T.intercalate "/" paths
+class Accept mt => ParseResponse (mt :: MediaType *) a where
+    parseResponse
+        :: MonadError Error m
+        => HTTP.Request -> HTTP.Response LBS.ByteString
+        -> Tagged mt (m a)
 
-    baseUrl :: Text
-    baseUrl = case auth of
-        Just (EnterpriseOAuth endpoint _)  -> endpoint
-        _                                  -> "https://api.github.com"
-
-    setReqHeaders :: HTTP.Request -> HTTP.Request
-    setReqHeaders req = req { requestHeaders = reqHeaders <> requestHeaders req }
-
-    setMethod :: Method -> HTTP.Request -> HTTP.Request
-    setMethod m req = req { method = m }
-
-    reqHeaders :: RequestHeaders
-    reqHeaders = maybe [] getOAuthHeader auth
-        <> [("User-Agent", "github.hs/0.7.4")]
-        <> [("Accept", "application/vnd.github.preview")]
-
-    setBody :: LBS.ByteString -> HTTP.Request -> HTTP.Request
-    setBody body req = req { requestBody = RequestBodyLBS body }
-
-    setAuthRequest :: Maybe Auth -> HTTP.Request -> HTTP.Request
-    setAuthRequest (Just (BasicAuth user pass)) = applyBasicAuth user pass
-    setAuthRequest _                                  = id
-
-    getOAuthHeader :: Auth -> RequestHeaders
-    getOAuthHeader (OAuth token)             = [("Authorization", "token " <> token)]
-    getOAuthHeader (EnterpriseOAuth _ token) = [("Authorization", "token " <> token)]
-    getOAuthHeader _                         = []
-
--- | Query @Link@ header with @rel=next@ from the request headers.
-getNextUrl :: Response a -> Maybe URI
-getNextUrl req = do
-    linkHeader <- lookup "Link" (responseHeaders req)
-    links <- parseLinkHeaderBS linkHeader
-    nextURI <- find isRelNext links
-    return $ href nextURI
-  where
-    isRelNext :: Link -> Bool
-    isRelNext = any (== relNextLinkParam) . linkParams
-
-    relNextLinkParam :: (LinkParam, Text)
-    relNextLinkParam = (Rel, "next")
+-------------------------------------------------------------------------------
+-- JSON (+ star)
+-------------------------------------------------------------------------------
 
 -- | Parse API response.
 --
 -- @
 -- parseResponse :: 'FromJSON' a => 'Response' 'LBS.ByteString' -> 'Either' 'Error' a
 -- @
-parseResponse :: (FromJSON a, MonadError Error m) => Response LBS.ByteString -> m a
-parseResponse res = case eitherDecode (responseBody res) of
+parseResponseJSON :: (FromJSON a, MonadError Error m) => Response LBS.ByteString -> m a
+parseResponseJSON res = case eitherDecode (responseBody res) of
     Right x  -> return x
     Left err -> throwError . ParseError . T.pack $ err
 
--- | Helper for handling of 'RequestStatus'.
---
--- @
--- parseStatus :: 'StatusMap' a -> 'Status' -> 'Either' 'Error' a
--- @
-parseStatus :: MonadError Error m => StatusMap a -> Status -> m a
-parseStatus m (Status sci _) =
-    maybe err return $ lookup sci m
-  where
-    err = throwError $ JsonError $ "invalid status: " <> T.pack (show sci)
+instance Accept 'MtJSON where
+    contentType = Tagged "application/vnd.github.v3+json"
+
+instance FromJSON a => ParseResponse 'MtJSON a where
+    parseResponse _ res = Tagged (parseResponseJSON res)
+
+instance Accept 'MtStar where
+    contentType = Tagged "application/vnd.github.v3.star+json"
+
+instance FromJSON a => ParseResponse 'MtStar a where
+    parseResponse _ res = Tagged (parseResponseJSON res)
+
+-------------------------------------------------------------------------------
+-- Raw / Diff / Patch / Sha
+-------------------------------------------------------------------------------
+
+instance Accept 'MtRaw   where contentType = Tagged "application/vnd.github.v3.raw"
+instance Accept 'MtDiff  where contentType = Tagged "application/vnd.github.v3.diff"
+instance Accept 'MtPatch where contentType = Tagged "application/vnd.github.v3.patch"
+instance Accept 'MtSha   where contentType = Tagged "application/vnd.github.v3.sha"
+
+instance a ~ LBS.ByteString => ParseResponse 'MtRaw   a where parseResponse _ = Tagged . return . responseBody
+instance a ~ LBS.ByteString => ParseResponse 'MtDiff  a where parseResponse _ = Tagged . return . responseBody
+instance a ~ LBS.ByteString => ParseResponse 'MtPatch a where parseResponse _ = Tagged . return . responseBody
+instance a ~ LBS.ByteString => ParseResponse 'MtSha   a where parseResponse _ = Tagged . return . responseBody
+
+-------------------------------------------------------------------------------
+-- Redirect
+-------------------------------------------------------------------------------
+
+instance Accept 'MtRedirect where
+    modifyRequest = Tagged $ \req ->
+        setRequestIgnoreStatus $ req { redirectCount = 0 }
+
+instance b ~ URI => ParseResponse 'MtRedirect b where
+    parseResponse req = Tagged . parseRedirect (getUri req)
 
 -- | Helper for handling of 'RequestRedirect'.
 --
@@ -357,6 +295,156 @@ parseRedirect originalUri rsp = do
   where
     noLocation = throwError $ ParseError "no location header in response"
 
+-------------------------------------------------------------------------------
+-- Extension point
+-------------------------------------------------------------------------------
+
+class PreviewAccept p where
+    previewContentType :: Tagged ('MtPreview p) BS.ByteString
+
+    previewModifyRequest :: Tagged ('MtPreview p) (HTTP.Request -> HTTP.Request)
+    previewModifyRequest = Tagged id
+
+class PreviewAccept p => PreviewParseResponse p a where
+    previewParseResponse
+        :: MonadError Error m
+        => HTTP.Request -> HTTP.Response LBS.ByteString
+        -> Tagged ('MtPreview p) (m a)
+
+instance PreviewAccept p => Accept ('MtPreview p) where
+    contentType   = previewContentType
+    modifyRequest = previewModifyRequest
+
+instance PreviewParseResponse p a => ParseResponse ('MtPreview p) a where
+    parseResponse = previewParseResponse
+
+-------------------------------------------------------------------------------
+-- Status
+-------------------------------------------------------------------------------
+
+instance Accept 'MtStatus where
+    modifyRequest = Tagged setRequestIgnoreStatus
+
+instance HasStatusMap a => ParseResponse 'MtStatus a where
+    parseResponse _ = Tagged . parseStatus statusMap . responseStatus
+
+type StatusMap a = [(Int, a)]
+
+class HasStatusMap a where
+    statusMap :: StatusMap a
+
+instance HasStatusMap Bool where
+    statusMap =
+        [ (204, True)
+        , (404, False)
+        ]
+
+instance HasStatusMap MergeResult where
+    statusMap =
+        [ (200, MergeSuccessful)
+        , (405, MergeCannotPerform)
+        , (409, MergeConflict)
+        ]
+
+-- | Helper for handling of 'RequestStatus'.
+--
+-- @
+-- parseStatus :: 'StatusMap' a -> 'Status' -> 'Either' 'Error' a
+-- @
+parseStatus :: MonadError Error m => StatusMap a -> Status -> m a
+parseStatus m (Status sci _) =
+    maybe err return $ lookup sci m
+  where
+    err = throwError $ JsonError $ "invalid status: " <> T.pack (show sci)
+
+-------------------------------------------------------------------------------
+-- Unit
+-------------------------------------------------------------------------------
+
+-- | Note: we don't ignore response status.
+--
+-- We only accept any response body.
+instance Accept 'MtUnit where
+
+instance a ~ () => ParseResponse 'MtUnit a where
+    parseResponse _ _ = Tagged (return ())
+
+------------------------------------------------------------------------------
+-- Tools
+------------------------------------------------------------------------------
+
+-- | Create @http-client@ 'Request'.
+--
+-- * for 'PagedQuery', the initial request is created.
+-- * for 'Status', the 'Request' for underlying 'Request' is created,
+--   status checking is modifying accordingly.
+--
+makeHttpRequest
+    :: forall am mt rw a m. (AuthMethod am, MonadThrow m, Accept mt)
+    => Maybe am
+    -> GenRequest mt rw a
+    -> m HTTP.Request
+makeHttpRequest auth r = case r of
+    Query paths qs -> do
+        req <- parseUrl' $ url paths
+        return
+            $ setReqHeaders
+            . unTagged (modifyRequest :: Tagged mt (HTTP.Request -> HTTP.Request))
+            . maybe id setAuthRequest auth
+            . setQueryString qs
+            $ req
+    PagedQuery paths qs _ -> do
+        req <- parseUrl' $ url paths
+        return
+            $ setReqHeaders
+            . unTagged (modifyRequest :: Tagged mt (HTTP.Request -> HTTP.Request))
+            . maybe id setAuthRequest auth
+            . setQueryString qs
+            $ req
+    Command m paths body -> do
+        req <- parseUrl' $ url paths
+        return
+            $ setReqHeaders
+            . unTagged (modifyRequest :: Tagged mt (HTTP.Request -> HTTP.Request))
+            . maybe id setAuthRequest auth
+            . setBody body
+            . setMethod (toMethod m)
+            $ req
+  where
+    parseUrl' :: MonadThrow m => String -> m HTTP.Request
+    parseUrl' = HTTP.parseUrlThrow
+
+    url :: Paths -> String
+    url paths = maybe "https://api.github.com" T.unpack (endpoint =<< auth) ++ "/" ++ intercalate "/" paths' where
+        paths' = map (escapeURIString isUnescapedInURIComponent . T.unpack) paths
+
+    setReqHeaders :: HTTP.Request -> HTTP.Request
+    setReqHeaders req = req { requestHeaders = reqHeaders <> requestHeaders req }
+
+    setMethod :: Method -> HTTP.Request -> HTTP.Request
+    setMethod m req = req { method = m }
+
+    reqHeaders :: RequestHeaders
+    reqHeaders = [("User-Agent", "github.hs/" <> fromString (showVersion version))] -- Version
+        <> [("Accept", unTagged (contentType :: Tagged mt BS.ByteString))]
+
+    setBody :: LBS.ByteString -> HTTP.Request -> HTTP.Request
+    setBody body req = req { requestBody = RequestBodyLBS body }
+
+-- | Query @Link@ header with @rel=next@ from the request headers.
+getNextUrl :: Response a -> Maybe URI
+getNextUrl req = do
+    linkHeader <- lookup "Link" (responseHeaders req)
+    links <- parseLinkHeaderBS linkHeader
+    nextURI <- find isRelNext links
+    return $ href nextURI
+  where
+    isRelNext :: Link -> Bool
+    isRelNext = any (== relNextLinkParam) . linkParams
+
+    relNextLinkParam :: (LinkParam, Text)
+    relNextLinkParam = (Rel, "next")
+
 -- | Helper for making paginated requests. Responses, @a@ are combined monoidally.
 --
 -- @
@@ -367,14 +455,14 @@ parseRedirect originalUri rsp = do
 --                     -> 'ExceptT' 'Error' 'IO' a
 -- @
 performPagedRequest
-    :: forall a m. (FromJSON a, Semigroup a, MonadCatch m, MonadError Error m)
+    :: forall a m mt. (ParseResponse mt a, Semigroup a, MonadCatch m, MonadError Error m)
     => (HTTP.Request -> m (Response LBS.ByteString))  -- ^ `httpLbs` analogue
     -> (a -> Bool)                                    -- ^ predicate to continue iteration
     -> HTTP.Request                                   -- ^ initial request
-    -> m a
-performPagedRequest httpLbs' predicate initReq = do
+    -> Tagged mt (m a)
+performPagedRequest httpLbs' predicate initReq = Tagged $ do
     res <- httpLbs' initReq
-    m <- parseResponse res
+    m <- unTagged (parseResponse initReq res :: Tagged mt (m a))
     go m res initReq
   where
     go :: a -> Response LBS.ByteString -> HTTP.Request -> m a
@@ -383,7 +471,7 @@ performPagedRequest httpLbs' predicate initReq = do
             (True, Just uri) -> do
                 req' <- HTTP.setUri req uri
                 res' <- httpLbs' req'
-                m <- parseResponse res'
+                m <- unTagged (parseResponse req' res' :: Tagged mt (m a))
                 go (acc <> m) res' req'
             (_, _)           -> return acc
 
@@ -391,35 +479,5 @@ performPagedRequest httpLbs' predicate initReq = do
 -- Internal
 -------------------------------------------------------------------------------
 
-
-setCheckStatus :: Maybe (StatusMap a) -> HTTP.Request -> HTTP.Request
-#if MIN_VERSION_http_client(0,5,0)
-setCheckStatus sm req = req { HTTP.checkResponse = successOrMissing sm }
-#else
-setCheckStatus sm req = req { HTTP.checkStatus = successOrMissing sm }
-#endif
-
-
-#if MIN_VERSION_http_client(0,5,0)
-successOrMissing :: Maybe (StatusMap a) -> HTTP.Request -> HTTP.Response HTTP.BodyReader -> IO ()
-successOrMissing sm _req res
-    | check     = pure ()
-    | otherwise = do
-        chunk <- HTTP.brReadSome (HTTP.responseBody res) 1024
-        let res' = fmap (const ()) res
-        HTTP.throwHttp $ HTTP.StatusCodeException res' (LBS.toStrict chunk)
-  where
-    Status sci _ = HTTP.responseStatus res
-#else
-successOrMissing :: Maybe (StatusMap a) -> Status -> ResponseHeaders -> HTTP.CookieJar -> Maybe E.SomeException
-successOrMissing sm s@(Status sci _) hs cookiejar
-    | check     = Nothing
-    | otherwise = Just $ E.toException $ StatusCodeException s hs cookiejar
-  where
-#endif
-    check = case sm of
-      Nothing  -> 200 <= sci && sci < 300
-      Just sm' -> sci `elem` map fst sm'
-
 onHttpException :: MonadError Error m => HttpException -> m a
 onHttpException = throwError . HTTPError
